# lockn-ai

**LockN AI — Intelligent automation platform by LockN Labs.**

Visit [lockn.ai](https://lockn.ai) for more information.

## Status

This package is in early development.

## License

[FSL-1.1-ALv2](./LICENSE.md) — Functional Source License, converting to Apache 2.0 after two years.

Copyright 2026 OneSun Labs LLC.
